@@ -1,6 +1,6 @@
 package Net::Twitter::Lite::API::V1_1;
 {
-  $Net::Twitter::Lite::API::V1_1::VERSION = '0.12002';
+  $Net::Twitter::Lite::API::V1_1::VERSION = '0.12003';
 }
 use warnings;
 use strict;
@@ -11,7 +11,7 @@ Net::Twitter::Lite::API::V1_1 - Twitter API v1.1 method definitions
 
 =head1 VERSION
 
-version 0.12002
+version 0.12003
 
 =cut
 
@@ -693,11 +693,11 @@ sub api_def () { +[
         } ],
 
 # Lists
-        [ 'all_subscriptions', {
-            aliases         => [ qw/all_lists list_subscriptions/ ],
+        [ 'get_lists', {
+            aliases         => [ qw/list_lists all_subscriptions/ ],
             path            => 'lists/list',
             method          => 'GET',
-            params          => [ qw/user_id screen_name/ ],
+            params          => [ qw/user_id screen_name reverse/ ],
             required        => [ qw// ],
             add_source      => 0,
             deprecated      => 0,
@@ -909,6 +909,18 @@ sub api_def () { +[
             booleans        => [ qw// ],
             base_url_method => 'apiurl',
         } ],
+        [ 'list_ownerships', {
+            aliases         => [],
+            path            => 'lists/ownerships',
+            method          => 'GET',
+            params          => [ qw/user_id screen_name count cursor/ ],
+            required        => [ qw// ],
+            add_source      => 0,
+            deprecated      => 0,
+            authenticate    => 1,
+            booleans        => [ qw// ],
+            base_url_method => 'apiurl',
+        } ],
 
 # Saved Searches
         [ 'saved_searches', {
